@@ -18,8 +18,8 @@ use strict;
 use Cwd;
 use Debian::Debhelper::Dh_Lib qw(
     complex_doit doit dpkg_architecture_value error escape_shell
-    getpackages make_symlink_raw_target install_dir print_and_doit
-    qx_cmd restore_file_on_clean tmpdir verbose_print );
+    get_buildoption getpackages make_symlink_raw_target install_dir
+    print_and_doit qx_cmd restore_file_on_clean tmpdir verbose_print );
 use Dpkg::Control::Info;
 use Dpkg::Deps;
 use File::Spec;
@@ -353,7 +353,7 @@ sub test ( $this, @params )
 
     # test generating Built-Using fields
     my $channel = get_buildoption("noopt") ? 'debug' : 'release';
-    doit(
+    $this->doit_in_sourcedir(
         "env",
         "DEB_BUILDDIR=" . $this->get_buildpath(),
         "CARGO_CHANNEL=$channel",
@@ -385,12 +385,9 @@ sub install ( $this, $destdir, @params )
             $this->_rel2rel( $crate->{packagepath}, "$target/.." ),
             $crate->{cratename}
         );
-        complex_doit(
-            qw(perl -MDigest::SHA=sha256_hex -gnE 'say sprintf),
-            'q<{"package":"%s","files":{}}>,', "sha256_hex($_)'",
-            "<",                               "$target/Cargo.toml",
-            ">",                               "$target/.cargo-checksum.json"
-        );
+        open(my $OUTFILE, ">", "$target/.cargo-checksum.json");
+        say $OUTFILE '{"package":"Could not get crate checksum","files":{}}';
+        close $OUTFILE;
 
         # prevent an ftpmaster auto-reject regarding files with old dates.
         doit(
@@ -434,7 +431,7 @@ sub install ( $this, $destdir, @params )
         );
 
         # generate Built-Using fields
-        doit(
+        $this->doit_in_sourcedir(
             "env",
             "DEB_BUILDDIR=" . $this->get_buildpath(),
             "/usr/share/dh-rust/bin/dh-rust-built-using",
